"""Top-level package for CoralNet-Toolbox."""

from coralnet_toolbox.main import run

__version__ = "0.0.21"
__author__ = "Jordan Pierce"
__email__ = "jordan.pierce@noaa.gov"
__credits__ = "National Center for Coastal and Ocean Sciences (NCCOS)"